| /llvm-project-15.0.7/llvm/test/CodeGen/SystemZ/ |
| H A D | ipra-04.ll | 1 ; Test that the updated regmask on the call to @fun1 preserves %r14 and 2 ; %15. @fun1 will save and restore these registers since it contains a call. 8 ; DBG: fun1 function optimized for not having CSR 10 ; DBG-NEXT: CallBRASL @fun1{{.*}} $r14d $r15d 14 define internal fastcc void @fun1(i16* %arg, i16* nocapture %arg1) unnamed_addr #0 { 31 call fastcc void @fun1(i16* nonnull undef, i16* %arg1)
|
| H A D | vec-perm-14.ll | 31 define <4 x i8> @fun1(<2 x i8> %arg) { 50 ; CHECK-NEXT: .globl fun1 52 ; CHECK-NEXT: .type fun1,@function 53 ; CHECK-NEXT: fun1: # @fun1
|
| H A D | tls-08.ll | 17 define i32 @fun1() { 18 ; CHECK: name: fun1
|
| H A D | load-and-test.mir | 32 # CHECK-LABEL: fun1 35 name: fun1
|
| H A D | fp-conv-18.ll | 5 ; CHECK-LABEL: fun1: 12 define void @fun1() #0 {
|
| /llvm-project-15.0.7/clang/test/SemaCXX/ |
| H A D | PR5086-ambig-resolution-enum.cpp | 7 const char * fun1(int , enum E) const; 8 int fun1(unsigned, const char *) const; 13 const char *p = rc.fun1(BUFLEN - 2, C::e1); in foo()
|
| H A D | warn-tautological-compare.cpp | 65 void fun1(); 79 if (fun1 == 0) {} in test() 93 if (nullptr != fun1) {} in test()
|
| H A D | recursive-lambda.cpp | 20 constexpr auto fun1(Number<IBegin> = Number<0>{}, Number<IEnd> = Number<1>{}) in fun1() function 37 fun1(); in fun2()
|
| /llvm-project-15.0.7/llvm/test/CodeGen/AArch64/ |
| H A D | semantic-interposition-asm.ll | 34 define dso_preemptable void @fun1() nounwind { 35 ; CHECK-LABEL: fun1: 48 ; CHECK-NEXT: adrp x8, :got:fun1 49 ; CHECK-NEXT: ldr x8, [x8, :got_lo12:fun1] 53 …ot:$2\0Aldr x8, [x8, :got_lo12:$2]", "=r,S,S,~{x8}"(void ()* nonnull @fun0, void ()* nonnull @fun1)
|
| H A D | aarch64-vcvtfp2fxs-combine.ll | 10 ; CHECK-LABEL: fun1 11 define void @fun1() local_unnamed_addr {
|
| H A D | prologue-epilogue-remarks.mir | 23 name: fun1 29 # CHECK: Function: fun1
|
| /llvm-project-15.0.7/flang/test/Evaluate/ |
| H A D | rewrite01.f90 | 116 function fun1(L) 117 character(L) :: fun1 local 119 end function fun1 155 print *, len(fun1(n-m))
|
| /llvm-project-15.0.7/llvm/test/CodeGen/X86/ |
| H A D | semantic-interposition-asm.ll | 43 define dso_preemptable void @fun1() nounwind { 44 ; COMMON-LABEL: fun1: 54 ; STATIC-NEXT: movq fun1@GOTPCREL(%rip), %rax 63 ; CHECK-NEXT: movq fun1@GOTPCREL(%rip), %rax 70 …$2, $0", "=r,*m,*m"(ptr elementtype(void ()) nonnull @fun0, ptr elementtype(void ()) nonnull @fun1)
|
| H A D | prologue-epilogue-remarks.mir | 6 define void @fun1() noredzone { ret void } 30 name: fun1 36 # CHECK-NEXT: Function: fun1
|
| /llvm-project-15.0.7/llvm/test/tools/llvm-split/ |
| H A D | scc-comdat.ll | 8 ; CHECK0: declare dso_local i32 @fun1 12 ; CHECK1: define internal i32 @fun1 18 define internal i32 @fun1() section ".text.funs" comdat($fun) {
|
| /llvm-project-15.0.7/llvm/test/CodeGen/Mips/micromips-sizereduction/ |
| H A D | micromips-lwp-swp.ll | 18 ; CHECK-NEXT: jal fun1 27 %call1 = call i32* @fun1() 32 declare i32* @fun1()
|
| /llvm-project-15.0.7/clang/test/SemaCUDA/ |
| H A D | dependent-device-var.cu | 7 __device__ int fun1(T x) { in fun1() function 16 return fun1(1); in fun1_caller()
|
| H A D | builtin-mangled-name.cu | 9 void fun1() { in fun1() function 20 p = __builtin_get_device_side_mangled_name(fun1); in fun1()
|
| /llvm-project-15.0.7/clang/test/CodeGenCUDA/ |
| H A D | unused-global-var.cu | 49 __device__ int fun1(const int& x); 52 *x = u1 + u2 + fun1(u3) + u4; in kern1()
|
| /llvm-project-15.0.7/clang/test/Sema/ |
| H A D | alias-redefinition.c | 7 void fun1() {} // expected-note {{previous definition}} in fun1() function 8 void fun1(void) __attribute((alias("f1"))); // expected-error {{redefinition of 'fun1'}}
|
| /llvm-project-15.0.7/flang/test/Semantics/ |
| H A D | resolve36.f90 | 13 module integer function fun1() 42 module integer function fun1()
|
| /llvm-project-15.0.7/llvm/test/CodeGen/Mips/ |
| H A D | micromips-sw.ll | 16 call i32* @fun1() 20 declare i32* @fun1()
|
| /llvm-project-15.0.7/llvm/test/Analysis/CostModel/SystemZ/ |
| H A D | cmp-tofp-scalar.ll | 15 define double @fun1(i64 %val1, i64 %val2) { 20 ; CHECK: fun1
|
| H A D | load-and-test.ll | 16 define i32 @fun1(i32* %Src, i32 %Arg) { 21 ; CHECK: function 'fun1'
|
| /llvm-project-15.0.7/llvm/test/Bitcode/ |
| H A D | function-nonzero-address-spaces-types.ll | 13 %fun1 = type i16 (i16) 14 %funptr1 = type %fun1 addrspace(40)*
|